@@ -48,7 +48,7 @@ from shtub.commandinput import CommandInput
 global lock_handle
 
 
-def record_execution (execution):
+def record_execution(execution):
     """
         loads the list of recent executions from the EXECUTIONS_FILENAME file,
         appends the given execution to the list, then writes the list back to
@@ -69,7 +69,7 @@ def record_execution (execution):
     unlock(lock_file_handle)
 
 
-def send_answer (answer):
+def send_answer(answer):
     """
         writes the stdout and stderr as given in the answer and performs a
         sys.exit with the given return_code.
@@ -86,26 +86,29 @@ def send_answer (answer):
     sys.exit(answer.return_code)
 
 
-def dispatch (command_input):
+def dispatch(command_input):
     """
         currently this will handle the given command_input by testing whether it
         fulfills a stub configuration. If so it will save a execution (with the expected flag
         set to true) and send the next answer as defined in the stub configuration object.
     """
 
-    stub_configurations = deserialize_stub_configurations(CONFIGURED_STUBS_FILENAME)
+    stub_configurations = deserialize_stub_configurations(
+        CONFIGURED_STUBS_FILENAME)
 
     logging.info('Got %s', command_input)
 
-    execution = Execution(command_input.command, command_input.arguments, command_input.stdin)
-    
+    execution = Execution(
+        command_input.command, command_input.arguments, command_input.stdin)
+
     for stub_configuration in stub_configurations:
         if command_input.fulfills(stub_configuration.command_input):
             logging.info('Execution fulfills %s', stub_configuration)
             execution.mark_as_expected()
             record_execution(execution)
             answer = stub_configuration.next_answer()
-            serialize_as_dictionaries(CONFIGURED_STUBS_FILENAME, stub_configurations)
+            serialize_as_dictionaries(
+                CONFIGURED_STUBS_FILENAME, stub_configurations)
             unlock(lock_handle)
             if answer.milliseconds_to_wait:
                 time.sleep(answer.milliseconds_to_wait / 1000)
@@ -113,17 +116,19 @@ def dispatch (command_input):
             return
 
     unlock(lock_handle)
-    logging.error('Given command_input does not fulfill requirements of any stub configuration.')
+    logging.error(
+        'Given command_input does not fulfill requirements of any stub configuration.')
     sys.exit(255)
 
 
-def read_stdin ():
+def read_stdin():
     """
         waits READ_STDIN_TIMEOUT_IN_SECONDS seconds for input on stdin and
         is going to return the complete input if there is any. If there is no
         input it is going to returns an empty string.
     """
-    read_list, _, _ = select([sys.stdin], [], [], READ_STDIN_TIMEOUT_IN_SECONDS)
+    read_list, _, _ = select(
+        [sys.stdin], [], [], READ_STDIN_TIMEOUT_IN_SECONDS)
 
     if len(read_list) > 0:
         return read_list[0].read()
@@ -131,7 +136,7 @@ def read_stdin ():
     return ''
 
 
-def handle_execution ():
+def handle_execution():
     """
         creates the base directory, initializes the logging and will read in
         the arguments and input from stdin to create a new execution object.
@@ -150,11 +155,11 @@ def handle_execution ():
     command = os.path.basename(sys.argv[0])
     arguments = sys.argv[1:]
     stdin = read_stdin()
-    
+
     command_input = CommandInput(command, arguments, stdin)
 
     dispatch(command_input)
 
 
-if __name__ == '__main__': # pragma: no cover
+if __name__ == '__main__':  # pragma: no cover
     handle_execution()
